@@ -15,6 +15,10 @@ GIS::Distance - Calculate geographic distances.
 This perl library aims to provide as many tools to make it as simple as possible to calculate
 distances between geographic points, and anything that can be derived from that.
 
+Please note that this is alpha software.  This module will become the
+replacement for L<Geo::Distance>.  So, until this module is
+well tested and production worthy I would recommend using that.
+
 =cut
 
 use strict;
@@ -23,12 +27,12 @@ use warnings;
 use base qw( Class::Data::Accessor );
 use Carp qw( croak );
 
-our $VERSION = '0.01000';
+our $VERSION = '0.01001';
 
 # Number of kilometers around the equator of the earth.
 __PACKAGE__->mk_classaccessor( kilometer_rho => 6371.64 );
 
-# Number of units in a single degree (lat or lon) at the equator.
+# Number of units in a single decimal degree (lat or lon) at the equator.
 # Derived from: $geo->distance( 10,0 => 11,0 )->km() / $geo->kilometer_rho()
 __PACKAGE__->mk_classaccessor( deg_ratio => 0.0174532925199433 );
 
@@ -63,6 +67,37 @@ Calculates the distance between two lon/lat points in decimal degree
 format.  In return you will receive an L<Class::Measure::Length>
 object.
 
+=head1 FORMULAS
+
+L<GID::Distance::Cosine>
+
+L<GID::Distance::GeoEllipsoid>
+
+L<GID::Distance::GreatCircle>
+
+L<GID::Distance::Haversine>
+
+L<GID::Distance::MathTrig>
+
+L<GID::Distance::Polar>
+
+L<GID::Distance::Vincenty>
+
+=head1 TODO
+
+Create a GIS::Coord class that represents a geographic coordinate.  Then modify
+this module to accept input as either lon/lat pairs, or as GIS::Coord objects.
+
+Create an extension to DBIx::Class with the same goal as L<Geo::Distance>'s
+closest() method.
+
+=head1 BUGS
+
+The graphs produce by graph_deviations.pl script show that the
+L<GIS::Distance::GreatCircle> formula is not performing well at
+all.  In most cases it is either returning a distance of 0 or a
+distance of 20,000 km.
+
 =head1 AUTHOR
 
 Aran Clary Deltac <bluefeet@cpan.org>
