@@ -31,6 +31,18 @@ use base qw( GIS::Distance );
 use Class::Measure::Length;
 use Math::Trig qw( deg2rad acos );
 
+=head1 METHODS
+
+=head2 distance
+
+  my $distance = $calc->distance( $lon1, $lat1 => $lon2, $lat2 );
+
+This method accepts two lat/lon sets (in decimal degrees) and returns a
+L<Class::Measure::Length> object containing the distance
+between the two points.
+
+=cut
+
 sub distance {
     my($self,$lon1,$lat1,$lon2,$lat2) = @_;
     $lon1 = deg2rad($lon1); $lat1 = deg2rad($lat1);
